from setuptools import setup

setup(name='nadima_distributions',
      version='0.1',
      description='Gaussian distributions',
      packages=['nadima_distributions'],
      author = 'Nadima Dwihusna',
      author_email = 'ndwihusn@alumni.mines.edu',
      zip_safe=False)
